Learn R Programming

psrwe (version 3.2)

summary.PSRWE_DTA: Summarize PS estimation and stratification results

Description

Get the number of subjects and the distances of PS distributions for each PS stratum.

Usage

# S3 method for PSRWE_DTA
summary(
  object,
  metric = c("ovl", "ksd", "std", "abd", "ley", "mhb", "omkss"),
  min_n0 = 10,
  ...
)

Value

A list with columns:

Summary

A data frame with Stratum, number of subjects in RWD, current study, number of subjects in control and treatment arms for RCT studies, and distance in PS distributions.

Overall

A data frame with the overall number of not-trimmed subjects in RWD, number of patients in the current study, number of subjects in control and treatment arms for RCT studies, and distance in PS distributions.

N

Vector of total number of total RWD patients, number of trimmed RWD patients, and total number of current study patients.

ps_fml

PS model.

Distance_metric

Metric used for calculating the distance.

Arguments

object

A list of class PSRWE_DAT that is generated using the psrwe_est function.

metric

Metric to use for calculating the distance with options:

ovl

Overlapping area

(default)
ksd

Kullback-Leibler distance

astd

Standardized absolute mean difference

std

Standardized mean difference

abd

Absolute difference in means

ley

Levy distance

mhb

Mahalanobis distance

omkss

One minus Kolmogorov-Smirnov statistic

min_n0

threshold for the number of external subjects, below which the external data in the current stratum will be ignored by setting the PS distance to 0. Default value 10.

...

Additional parameters.

Examples

Run this code
data(ex_dta)
dta_ps <- psrwe_est(ex_dta,
                     v_covs = paste("V", 1:7, sep = ""),
                     v_grp = "Group",
                     cur_grp_level = "current")
dta_ps

## With different similarity metric
print(dta_ps, metric = "omkss")
dta_ps_sum <- summary(dta_ps, metric = "omkss")

Run the code above in your browser using DataLab