summary.PSRWE_DTA_MAT: Summarize PS estimation and matching results

View source: R/psrwe_ps_match.R

summary.PSRWE_DTA_MATR Documentation

Summarize PS estimation and matching results

Description

Get number of subjects for each PS stratum.

Usage

## S3 method for class 'PSRWE_DTA_MAT'
summary(object, ...)

Arguments

object

A list of class PSRWE_DTA_MAT that is generated using the psrwe_match function.

...

Additional parameters.

Value

A list with columns:

Summary

A data frame with Stratum (defined by covariates), number of subjects in RWD, current study, number of subjects in control and treatment arms for RCT studies.

Overall

A data frame with overall number of not-trimmed subjects in RWD, number of patients in current study, number of subjects in control and treatment arms for RCT studies.

N

Vector of total number of total RWD patients, number of trimmed RWD patients, total number of current study patients, number of current control patients with less than ratio matched RWD subjects.

ps_fml

PS model.

N_Match

Number of current control subjects matched with ratio, 0 and other number of RWD subjects.

ratio

Matching ratio.


olssol/psrwe documentation built on July 17, 2024, 4:06 p.m.