View source: R/psrwe_ps_match.R
| summary.PSRWE_DTA_MAT | R Documentation |
Get number of subjects for each PS stratum.
## S3 method for class 'PSRWE_DTA_MAT'
summary(object, ...)
object |
A list of class |
... |
Additional parameters. |
A list with columns:
A data frame with Stratum (defined by covariates), number of subjects in RWD, current study, number of subjects in control and treatment arms for RCT studies.
A data frame with overall number of not-trimmed subjects in RWD, number of patients in current study, number of subjects in control and treatment arms for RCT studies.
Vector of total number of total RWD patients, number of trimmed
RWD patients, total number of current study patients, number of current
control patients with less than ratio matched RWD subjects.
PS model.
Number of current control subjects matched with
ratio, 0 and other number of RWD subjects.
Matching ratio.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.